@@ -9,8 +9,6 @@ __all__ = [
     "dual_areas",
     "find_mesh_boundaries",
     "fix_normals",
-    "get_line_quad_points",
-    "get_quad_points",
     "inner2vert",
     "load_example_mesh",
     "tri_normals_and_areas",
@@ -23,12 +21,7 @@ import numpy as np
 import pkg_resources
 import trimesh
 
-try:
-    from quadpy import triangle
-    from quadpy import line_segment
-except ImportError:
-    from quadpy import t2 as triangle
-    from quadpy import c1 as line_segment
+from .quadratures import get_quad_points
 
 
 def combine_meshes(meshes):
@@ -73,107 +66,6 @@ def tri_normals_and_areas(r, tri):
     return n, a
 
 
-def get_quad_points(verts, tris, method, return_ref_coords=False):
-    """Get quad points and weights from quadrature rules implemented in
-    quadpy
-
-    Parameters
-    ----------
-    verts: array-like [Nverts x 3]
-    tris: array-like [Ntris x 3]
-    method: string
-
-    Returns
-    -------
-    w: array-like  (Nquad, )
-        quadrature weights
-    qp: array-like (Ntris, Nquad)
-        quadrature points in each triangle
-
-    """
-    try:
-        rule = triangle.schemes[method]()
-    except (TypeError) as error:
-
-        print(
-            "The quadrature method specified requires does not exist (check quadpy documentation)"
-        )
-        raise error
-
-    x = rule.points.T[:, 0:2]
-    w = rule.weights
-
-    qp = np.zeros((tris.shape[0], len(w), 3))
-    for i, t in enumerate(tris):
-        p0 = verts[t[0]]
-        p1 = verts[t[1]]
-        p2 = verts[t[2]]
-        B = np.array([p1 - p0, p2 - p0])
-
-        qp[i] = x @ B + p0
-
-    if return_ref_coords:
-        return w, qp, x
-    else:
-        return w, qp
-
-
-def get_line_quad_points(line_vertices, method="midpoint", index=None):
-    """Get quad points and weights from quadrature rules implemented in
-    quadpy
-
-    Parameters
-    ----------
-    line_vertices: array-like [Nverts x 3]
-        Assumes vertices are connected according to index, last index connects to first
-
-    Returns
-    -------
-    w: array-like  (Nquad, )
-        quadrature weights
-    qp: array-like (Nverts, Nquad)
-        quadrature points for each edge connecting the vertices
-
-    """
-    methods = [k for k in line_segment.__all__]  # if k[0].isupper()]
-    if method in methods:
-        try:
-            rule = line_segment.__dict__[method]()
-        except (TypeError) as error:
-            if index is not None:
-                rule = line_segment.__dict__[method](index)
-            else:
-                print("The method requires index (check quadpy documentation)")
-                raise error
-    else:
-        raise ValueError(
-            "method: "
-            + method
-            + " not in the available list of methods (check quadpy.line_segment.__all__)"
-        )
-
-    x = rule.points
-    w = rule.weights
-
-    #    tris -> edges
-
-    qp = np.zeros((len(line_vertices), len(w), 3))
-
-    for i in range(len(line_vertices)):
-        p0 = line_vertices[i]
-
-        if i == len(line_vertices) - 1:
-            p1 = line_vertices[0]
-        else:
-            p1 = line_vertices[i + 1]
-
-        B = np.array([p1 - p0])
-
-        qp[i] = x[:, None] @ B / 2 + B / 2 + p0
-
-    return w, qp
-
-
 def dual_areas(tris, ta):
     """Calculate (dual) areas for each node in inds
 
@@ -444,7 +336,7 @@ class MeshProjection:
         self.mesh = mesh
 
         weights, self.quadpoints, ref_coords = get_quad_points(
-            mesh.vertices, mesh.faces, "dunavant_0" + str(quad_degree), None, True
+            mesh.vertices, mesh.faces, ("dunavant", quad_degree), return_ref_coords=True
         )
         # Mapping from coordinates of a reference triangle to barycentric coordinates
         self.M = np.array([[-1.0, -1.0, 1.0], [1.0, 0.0, 0.0], [0.0, 1.0, 0.0]])
