@@ -111,7 +111,9 @@ if PLOT:
 
     if SAVE_FIGURES:
         mlab.savefig(
-            SAVE_DIR + "shielded_biplanar_geometry.png", figure=f, magnification=4,
+            SAVE_DIR + "shielded_biplanar_geometry.png",
+            figure=f,
+            magnification=4,
         )
         mlab.close()
 
@@ -168,7 +170,9 @@ if PLOT:
 
     if SAVE_FIGURES:
         mlab.savefig(
-            SAVE_DIR + "shielded_biplanar_ignored.png", figure=f, magnification=4,
+            SAVE_DIR + "shielded_biplanar_ignored.png",
+            figure=f,
+            magnification=4,
         )
         mlab.close()
 #%%
@@ -254,7 +258,9 @@ if PLOT:
     f.scene.camera.zoom(0.95)
     if SAVE_FIGURES:
         mlab.savefig(
-            SAVE_DIR + "shielded_biplanar_prospective.png", figure=f, magnification=4,
+            SAVE_DIR + "shielded_biplanar_prospective.png",
+            figure=f,
+            magnification=4,
         )
         mlab.close()
 
